@@ -21,9 +21,6 @@
 #
 # ---------------------------------------------------------------------------##
 
-
-import imp
-
 import pysollib.settings
 from pysollib.mfxutil import Struct, print_err
 from pysollib.mygettext import _, n_
@@ -31,6 +28,16 @@ from pysollib.resource import CSI
 
 import six
 
+# Handle import of import library - different libraries are needed
+# for different Python versions.
+imp = None
+util = None
+try:
+    from importlib import util
+except ImportError:
+    util = None
+    import imp
+
 # ************************************************************************
 # * constants
 # ************************************************************************
@@ -48,6 +55,9 @@ class GI:
     GC_NAVAGRAHA_GANJIFA = CSI.TYPE_NAVAGRAHA_GANJIFA
     GC_DASHAVATARA_GANJIFA = CSI.TYPE_DASHAVATARA_GANJIFA
     GC_TRUMP_ONLY = CSI.TYPE_TRUMP_ONLY
+    GC_MATCHING = CSI.TYPE_MATCHING
+
+    NUM_CATEGORIES = CSI.TYPE_MATCHING
 
     # game type
     GT_1DECK_TYPE = 0
@@ -288,6 +298,7 @@ class GI:
          155: 5034,             # Mahjongg - Flying Dragon
          156: 5035,             # Mahjongg - Fortress Towers
          262: 105,              # Canfield
+         283: 25,               # Gargantua/Jumbo
          902: 88,               # Trefoil
          904: 68,               # Lexington Harp
          237: 22231,            # Three Peaks
@@ -330,8 +341,7 @@ class GI:
         # Gnome AisleRiot 2.2.0 (we have 65 out of 70 games)
         # Gnome AisleRiot 3.22.7
         #   still missing:
-        #       Hamilton, Isabel, King's Audience, Labyrinth, Thieves,
-        #       Treize, Valentine, Wall
+        #       Hamilton, Labyrinth, Thieves, Treize, Valentine, Wall
         ("Gnome AisleRiot", (
             1, 2, 8, 9, 11, 12, 13, 19, 24, 27, 29, 31, 33, 34, 35, 36,
             38, 40, 41, 42, 43, 45, 48, 58, 65, 67, 89, 91, 92, 93, 94,
@@ -339,7 +349,7 @@ class GI:
             146, 147, 148, 200, 201, 206, 224, 225, 229, 230, 233, 257,
             258, 277, 280, 281, 282, 283, 284, 334, 384, 479, 495, 551,
             552, 553, 572, 593, 674, 700, 715, 716, 737, 772, 810, 819,
-            824, 829, 22231,
+            824, 829, 859, 874, 22231,
         )),
 
         # Hoyle Card Games
@@ -359,8 +369,10 @@ class GI:
         #  KDE Patience 2.0 from KDE 2.2beta1 (we have 12 out of 14 games)
         # ("KDE Patience", (1, 2, 7, 8, 18, 19, 23, 36, 50, 256, 261, 903,)),
         # KDE Patience 2.0 from KDE 3.1.1 (we have 15 out of 15 games)
-        ("KDE Patience", (1, 2, 7, 8, 18, 19, 23, 36, 50,
-                          256, 261, 277, 278, 279, 903,)),
+        # ("KDE Patience", (1, 2, 7, 8, 18, 19, 23, 36, 50,
+        #                256, 261, 277, 278, 279, 903,)),
+        # Now KPatience - Calculation and Napoleon's Tomb have been removed.
+        ("KPatience", (1, 2, 7, 8, 11, 18, 19, 23, 36, 50, 261, 278, 903,)),
 
         # Microsoft Solitaire (we have all 5 games)
         ("Microsoft Solitaire Collection", (2, 8, 11, 38, 22231,)),
@@ -373,8 +385,7 @@ class GI:
 
         # Solitude for Windows
         # still missing:
-        #       Bowling (Sackson version), Four Kingdoms, Icicles,
-        #       Six By Six
+        #       Bowling (Sackson version), Four Kingdoms, Icicles
         ("Solitude for Windows", (
             2, 8, 11, 13, 19, 24, 25, 29, 30, 31, 33, 34, 36, 38, 42,
             43, 45, 48, 50, 53, 56, 57, 58, 62, 64, 67, 69, 71, 86, 87,
@@ -382,7 +393,7 @@ class GI:
             128, 133, 134, 135, 139, 146, 147, 171, 172, 173, 221, 222,
             224, 228, 233, 234, 235, 256, 257, 258, 282, 314, 327, 330,
             355, 356, 398, 406, 414, 418, 434, 437, 484, 593, 715, 716,
-            737, 751, 805, 830, 845, 847, 901, 903
+            737, 751, 805, 830, 845, 847, 888, 901, 903
         )),
 
         # XM Solitaire
@@ -393,16 +404,15 @@ class GI:
         # from XM Solitaire should be researched before being added to PySol.
         #
         # still missing:
-        #       Ace of Hearts, Affinity, Agnes Three, Antares, Avenue,
-        #       Baker's Fan, Baker's Spider, Bedeviled, Binding,
-        #       Black Holes, Black Spider, California, Carcassone,
-        #       Cascade, Club, Color Cell, Cornelius, Demons and Thieves,
-        #       Desert Fox, Deuces and Queens, Double Antares,
+        #       Ace of Hearts, Agnes Three, Antares, Avenue, Baker's Fan,
+        #       Baker's Spider, Bedeviled, Binding, Black Holes,
+        #       Black Spider, California, Cascade, Club, Color Cell,
+        #       Cornelius, Desert Fox, Deuces and Queens, Double Antares,
         #       Double Antarctica, Double Arctica, Double Baker's Spider,
-        #       Double Cascade, Double Fourteens, Double Line 8,
-        #       Double Majesty, Double Spidercells, Doublet Cell 5, Doubt,
-        #       Dream Fan, Dumfries Cell, Falcon Wing, Fan Nine, Fanny 6,
-        #       Four By Ten, FreeCell AK, Gaps Alter, Gaps Diff, George V,
+        #       Double Cascade, Double Line 8, Double Majesty,
+        #       Double Spidercells, Doublet Cell 5, Doubt, Dream Fan,
+        #       Dumfries Cell, Falcon Wing, Fan Nine, Fanny 6, Four By Ten,
+        #       FreeCell AK, Gaps Alter, Gaps Diff, George V,
         #       Grandmother's Clock, In a Frame, Inverted FreeCell, Kings,
         #       Klondike FreeCell, La Cabane, La Double Entente,
         #       Little Gazette, Magic FreeCell, Mini Gaps, Montreal,
@@ -423,7 +433,8 @@ class GI:
             364, 372, 376, 383, 384, 385, 386, 390, 391, 393, 398, 405,
             415, 416, 425, 451, 453, 461, 464, 466, 467, 476, 480, 484,
             511, 512, 513, 516, 561, 610, 625, 629, 631, 638, 641, 647,
-            650, 655, 678, 734, 751, 784, 825, 829, 834, 837, 844, 901,
+            650, 655, 678, 684, 734, 751, 784, 825, 829, 834, 837, 844,
+            862, 867, 880, 889, 901,
         )),
 
         # xpat2 1.06 (we have 14 out of 16 games)
@@ -441,19 +452,21 @@ class GI:
         ("Art Cabral", (9,)),
         ("Richard A. Canfield", (105, 835,)),
         ("Lillian Davies and Christa Baran", (605,)),
+        ("Ann Edwards", (869,)),
         ("Robert Harbin", (381,)),
         ("Robert Hogue", (22216, 22217, 22218, 22231,)),
         ("Erik den Hollander", (344, 544,)),
         ("Rick Holzgrafe", (756, 757,)),
-        ("Charles Jewell", (220, 309,)),
-        ("Michael Keller", (592,)),
+        ("Charles Jewell", (220, 309, 894,)),
+        ("Michael Keller", (592, 883,)),
         ("Fred Lunde", (459,)),
+        ("Mark Masten", (811,)),
         ("Albert Morehead and Geoffrey Mott-Smith", (25, 42, 48, 173, 282,
                                                      303, 362, 547, 738,
                                                      845)),
         ("Toby Ord", (788,)),
         ("David Parlett", (64, 98, 294, 338, 654, 796, 812, 844)),
-        ("Randy Rasa", (187, 190, 191, 192,)),
+        ("Randy Rasa", (187, 188, 190, 191, 192,)),
         ("Gregg Seelhoff", (347,)),
         ("Adam Selene", (366,)),
         ("Jim Sizelove", (555001,)),
@@ -461,9 +474,10 @@ class GI:
         ("John Stoneham", (201,)),
         ("Bryan Stout", (655,)),
         ("Bill Taylor", (349,)),
+        ("Peter Voke", (876,)),
         ("Thomas Warfield", (189, 264, 300, 320, 336, 337, 359,
                              415, 427, 458, 495, 496, 497, 508,
-                             800, 814, 820, 825,)),
+                             800, 814, 820, 825, 889,)),
         ("Mary Whitmore Jones", (421, 624,)),
         )
 
@@ -543,12 +557,14 @@ class GI:
         ('fc-2.12',   tuple(range(774, 811)) + (16681,) +
          tuple(range(22217, 22219))),
         ('fc-2.14', tuple(range(811, 827))),
-        ('fc-2.15', tuple(range(827, 855)) + tuple(range(22400, 22407)))
+        ('fc-2.15', tuple(range(827, 855)) + tuple(range(22400, 22407))),
+        ('fc-2.20', tuple(range(855, 897)))
     )
 
     # deprecated - the correct way is to or a GI.GT_XXX flag
     # in the registerGame() call
-    _CHILDREN_GAMES = [16, 33, 55, 90, 91, 96, 97, 176, 328, 329, 903, ]
+    _CHILDREN_GAMES = [16, 33, 55, 90, 91, 96, 97, 176, 328, 329, 862, 865,
+                       886, 903, ]
 
     _OPEN_GAMES = []
 
@@ -624,7 +640,7 @@ class GameInfo(Struct):
         if pysollib.settings.TRANSLATE_GAME_NAMES:
             altnames = [_(n) for n in altnames]
         #
-        if not (1 <= category <= 9):
+        if not (1 <= category <= GI.NUM_CATEGORIES):
             if game_type == GI.GT_HANAFUDA:
                 category = GI.GC_HANAFUDA
             elif game_type == GI.GT_TAROCK:
@@ -742,6 +758,7 @@ class GameManager:
         # if 0 and gi.si.game_flags & GI.GT_XORIGINAL:
         #     return
         # print gi.id, gi.name
+        gi.altnames = sorted(gi.altnames)
         self.__all_games[gi.id] = gi
         self.__all_gamenames[gi.name] = gi
         for n in gi.altnames:
@@ -792,13 +809,13 @@ class GameManager:
         if self.__games_by_name is None:
             l1, l2, l3 = [], [], []
             for id, gi in self.__games.items():
-                name = gi.name  # .lower()
+                name = gi.name .lower()
                 l1.append((name, id))
                 if gi.name != gi.short_name:
-                    name = gi.short_name  # .lower()
+                    name = gi.short_name.lower()
                 l2.append((name, id))
                 for n in gi.altnames:
-                    name = n  # .lower()
+                    name = n.lower()
                     l3.append((name, id, n))
             l1.sort()
             l2.sort()
@@ -852,6 +869,12 @@ def loadGame(modname, filename, check_game=False):
     # print "load game", modname, filename
     GAME_DB.check_game = check_game
     GAME_DB.current_filename = filename
-    imp.load_source(modname, filename)
+    if util is not None:
+        spec = util.spec_from_file_location(modname, filename)
+        module = util.module_from_spec(spec)
+        spec.loader.exec_module(module)
+    else:
+        imp.load_source(modname, filename)
+
     # execfile(filename, globals(), globals())
     GAME_DB.current_filename = None
