@@ -138,6 +138,10 @@ class FanGame(Fan):
     Solver_Class = FreeCellSolverWrapper(preset='fan')
 
 
+class CeilingFan(Fan):
+    RowStack_Class = KingAC_RowStack
+
+
 # ************************************************************************
 # * Scotch Patience
 # ************************************************************************
@@ -275,7 +279,7 @@ class ThreeShufflesAndADraw_RowStack(SS_RowStack):
         game.updateStackMove(r, 3 | 64)       # update model
         game.updateStackMove(r, 1 | 16)       # update view for redo
         # 2) second card from self to foundation/row
-        if 1 or not game.demo:
+        if not game.demo:
             game.playSample("drop", priority=200)
         if frames == 0:
             frames = -1
@@ -331,7 +335,7 @@ class ThreeShufflesAndADraw(LaBelleLucie):
     RowStack_Class = StackWrapper(
         ThreeShufflesAndADraw_RowStack, base_rank=NO_RANK)
 
-    def createGame(self):
+    def createGame(self, texts=True):
         lay = LaBelleLucie.createGame(self)
         s = self.s
         # add a reserve stack
@@ -357,6 +361,35 @@ class ThreeShufflesAndADraw(LaBelleLucie):
         p.dump(self.draw_done)
 
 
+# ************************************************************************
+# * Cromwell
+# ************************************************************************
+
+class Cromwell(ThreeShufflesAndADraw):
+    Foundation_Classes = [SS_FoundationStack, SS_FoundationStack]
+    Talon_Class = InitialDealTalonStack
+    RowStack_Class = StackWrapper(
+        ThreeShufflesAndADraw_RowStack, base_rank=NO_RANK, max_move=999999)
+
+    def createGame(self, texts=True):
+        lay = Fan.createGame(self, rows=(6, 6, 6, 6, 2))
+        s = self.s
+        # add a reserve stack
+        x, y = s.rows[3].x, s.rows[-1].y
+        s.reserves.append(ThreeShufflesAndADraw_ReserveStack(x, y, self))
+        # redefine the stack-groups
+        lay.defaultStackGroups()
+        # extra settings
+        self.draw_done = 0
+
+    def startGame(self):
+        self.draw_done = 0
+        self.s.reserves[0].updateText()
+        for i in range(3):
+            self.s.talon.dealRow(rows=self.s.rows[:26], frames=0)
+        self._startAndDealRow()
+
+
 # ************************************************************************
 # * Trefoil
 # ************************************************************************
@@ -607,10 +640,10 @@ class BoxFan(Fan):
 
 # ************************************************************************
 # * Troika
+# * Quads
 # ************************************************************************
 
 class Troika(Fan):
-
     RowStack_Class = StackWrapper(RK_RowStack, dir=0,
                                   base_rank=NO_RANK, max_cards=3)
 
@@ -663,6 +696,42 @@ class QuadsPlus(Quads):
         self.s.talon.dealRow(rows=self.s.rows[:-1])
 
 
+# ************************************************************************
+# * Roaming Proils
+# ************************************************************************
+
+class RoamingProils_RowStack(RK_RowStack):
+
+    def acceptsCards(self, from_stack, cards):
+        if not RK_RowStack.acceptsCards(self, from_stack, cards):
+            return False
+        rank_sequence = 1
+        for card in reversed(self.cards):
+            if card.rank == cards[0].rank and card.face_up:
+                rank_sequence += 1
+            else:
+                break
+
+        if rank_sequence > 3:
+            return False
+        return True
+
+
+class RoamingProils(Fan):
+    RowStack_Class = StackWrapper(RoamingProils_RowStack, dir=0,
+                                  base_rank=NO_RANK)
+    ReserveStack_Class = StackWrapper(ReserveStack, base_rank=KING)
+
+    def createGame(self):
+        Fan.createGame(self, rows=(5, 5, 5, 2), playcards=5, reserves=1)
+
+    def startGame(self):
+        for i in range(2):
+            self.s.talon.dealRow(rows=self.s.rows[:17], flip=0, frames=0)
+        self._startAndDealRow()
+        self.s.talon.dealRow(rows=self.s.reserves)
+
+
 # ************************************************************************
 # * Fascination Fan
 # ************************************************************************
@@ -1052,7 +1121,7 @@ registerGame(GameInfo(57, Shamrocks, "Shamrocks",
                       GI.GT_FAN_TYPE | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(901, LaBelleLucie, "La Belle Lucie",      # was: 32, 82
                       GI.GT_FAN_TYPE | GI.GT_OPEN, 1, 2, GI.SL_MOSTLY_SKILL,
-                      altnames=("Fair Lucy", "Midnight Oil")))
+                      altnames=("Fair Lucy", "Midnight Oil", "Lovely Lucy")))
 registerGame(GameInfo(132, SuperFlowerGarden, "Super Flower Garden",
                       GI.GT_FAN_TYPE | GI.GT_OPEN, 1, 2, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(128, ThreeShufflesAndADraw, "Three Shuffles and a Draw",
@@ -1082,7 +1151,8 @@ registerGame(GameInfo(625, FascinationFan, "Fascination Fan",
                       GI.GT_FAN_TYPE, 1, 6, GI.SL_BALANCED,
                       altnames=('Demon Fan',)))
 registerGame(GameInfo(647, Crescent, "Crescent",
-                      GI.GT_FAN_TYPE | GI.GT_OPEN, 2, 3, GI.SL_MOSTLY_SKILL))
+                      GI.GT_FAN_TYPE | GI.GT_OPEN, 2, 3, GI.SL_MOSTLY_SKILL,
+                      altnames=('La Demi-Lune',)))
 registerGame(GameInfo(714, ShamrocksII, "Shamrocks II",
                       GI.GT_FAN_TYPE | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(719, School, "School",
@@ -1096,3 +1166,9 @@ registerGame(GameInfo(819, BearRiver, "Bear River",
                       GI.GT_FAN_TYPE | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(834, RainbowFan, "Rainbow Fan",
                       GI.GT_FAN_TYPE, 2, 3, GI.SL_MOSTLY_SKILL))
+registerGame(GameInfo(871, CeilingFan, "Ceiling Fan",
+                      GI.GT_FAN_TYPE | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL))
+registerGame(GameInfo(879, RoamingProils, "Roaming Proils",
+                      GI.GT_FAN_TYPE, 1, 0, GI.SL_BALANCED))
+registerGame(GameInfo(894, Cromwell, "Cromwell",
+                      GI.GT_FAN_TYPE | GI.GT_OPEN, 2, 0, GI.SL_MOSTLY_SKILL))
