@@ -43,7 +43,8 @@ from pysollib.stack import \
         WasteStack, \
         WasteTalonStack
 from pysollib.util import ACE, ANY_RANK, ANY_SUIT, CLUB, DIAMOND,\
-        HEART, KING, NO_RANK, SPADE, UNLIMITED_MOVES, UNLIMITED_REDEALS
+        HEART, JACK, KING, NO_RANK, SPADE, UNLIMITED_MOVES,\
+        UNLIMITED_REDEALS
 
 
 class FortyThieves_Hint(CautiousDefaultHint):
@@ -685,15 +686,19 @@ class Octave(Game):
 # ************************************************************************
 
 class FortunesFavor(Game):
+    ROWS = 2
+    COLS = 6
 
     def createGame(self):
 
         l, s = Layout(self), self.s
 
-        w, h = l.XM+8*l.XS, 2*l.YM+3*l.YS
+        w, h = l.XM + (2 + self.COLS) * l.XS, 2 * l.YM + (1 + self.ROWS) * l.YS
         self.setSize(w, h)
 
-        x, y = l.XM+3*l.XS, l.YM
+        offset = 2 + ((self.COLS - 4) / 2)
+
+        x, y = l.XM + offset * l.XS, l.YM
         for i in range(4):
             s.foundations.append(SS_FoundationStack(x, y, self, suit=i))
             x += l.XS
@@ -704,9 +709,9 @@ class FortunesFavor(Game):
         s.waste = WasteStack(x, y, self)
         l.createText(s.waste, 'se')
         y = 2*l.YM+l.YS
-        for i in range(2):
+        for i in range(self.ROWS):
             x = l.XM+2*l.XS
-            for j in range(6):
+            for j in range(self.COLS):
                 stack = SS_RowStack(x, y, self, max_move=1)
                 stack.CARD_XOFFSET, stack.CARD_YOFFSET = 0, 0
                 s.rows.append(stack)
@@ -734,6 +739,15 @@ class FortunesFavor(Game):
     shallHighlightMatch = Game._shallHighlightMatch_SS
 
 
+# ************************************************************************
+# * Preference
+# ************************************************************************
+
+class Preference(FortunesFavor):
+    ROWS = 2
+    COLS = 4
+
+
 # ************************************************************************
 # * Octagon
 # ************************************************************************
@@ -838,6 +852,52 @@ class Squadron(FortyThieves):
         self.s.talon.dealCards()          # deal first card to WasteStack
 
 
+# ************************************************************************
+# * Jacks in the Box
+# ************************************************************************
+
+class JacksInTheBox(FortyThieves):
+
+    def createGame(self):
+        l, s = Layout(self), self.s
+
+        self.setSize(l.XM + 11 * l.XS,
+                     l.YM+max(5.5 * l.YS, 2 * l.YS + 12 * l.YOFFSET))
+
+        x, y = l.XM, l.YM
+        s.talon = WasteTalonStack(x, y, self, max_rounds=1)
+        l.createText(s.talon, 's')
+        x += l.XS
+        s.waste = WasteStack(x, y, self)
+        l.createText(s.waste, 's')
+        x += 2 * l.XS
+        for i in range(8):
+            s.foundations.append(SS_FoundationStack(x, y, self, suit=i//2,
+                                                    mod=13, base_rank=JACK))
+            x += l.XS
+        x, y = l.XM, l.YM + l.YS * 3 // 2
+        for i in range(4):
+            s.reserves.append(ReserveStack(x, y, self))
+            y += l.YS
+        x, y = l.XM + 4 * l.XS, l.YM + l.YS
+        for i in range(6):
+            s.rows.append(SS_RowStack(x, y, self, max_move=1, mod=13))
+            x += l.XS
+
+        l.defaultStackGroups()
+
+    def _shuffleHook(self, cards):
+        # move Twos to top of the Talon (i.e. first cards to be dealt)
+        return self._shuffleHookMoveToTop(
+            cards, lambda c: (c.rank == JACK, c.suit))
+
+    def startGame(self):
+        self.startDealSample()
+        self.s.talon.dealRow(rows=self.s.foundations)
+        self.s.talon.dealRow()
+        self.s.talon.dealCards()
+
+
 # ************************************************************************
 # * Waterloo
 # ************************************************************************
@@ -1332,8 +1392,8 @@ class Following(FortyThieves):
 # register the game
 registerGame(GameInfo(13, FortyThieves, "Forty Thieves",
                       GI.GT_FORTY_THIEVES, 2, 0, GI.SL_MOSTLY_SKILL,
-                      altnames=("Napoleon at St. Helena",
-                                "Le Cadran")))
+                      altnames=("Napoleon at St. Helena", "Le Cadran",
+                                "Roosevelt at San Juan")))
 registerGame(GameInfo(80, BusyAces, "Busy Aces",
                       GI.GT_FORTY_THIEVES, 2, 0, GI.SL_BALANCED))
 registerGame(GameInfo(228, Limited, "Limited",
@@ -1343,7 +1403,8 @@ registerGame(GameInfo(79, WaningMoon, "Waning Moon",
 registerGame(GameInfo(125, Lucas, "Lucas",
                       GI.GT_FORTY_THIEVES, 2, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(109, Deuces, "Deuces",
-                      GI.GT_FORTY_THIEVES, 2, 0, GI.SL_MOSTLY_SKILL))
+                      GI.GT_FORTY_THIEVES, 2, 0, GI.SL_MOSTLY_SKILL,
+                      altnames=("Twos", "Les Deux")))
 registerGame(GameInfo(196, Corona, "Corona",
                       GI.GT_FORTY_THIEVES, 2, 0, GI.SL_BALANCED))
 registerGame(GameInfo(195, Quadrangle, "Quadrangle",
@@ -1399,7 +1460,8 @@ registerGame(GameInfo(426, Octagon, "Octagon",
 registerGame(GameInfo(440, Squadron, "Squadron",
                       GI.GT_FORTY_THIEVES, 2, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(462, Josephine, "Josephine",
-                      GI.GT_FORTY_THIEVES, 2, 0, GI.SL_MOSTLY_SKILL))
+                      GI.GT_FORTY_THIEVES, 2, 0, GI.SL_MOSTLY_SKILL,
+                      altnames=("Forty Bandits")))
 registerGame(GameInfo(493, MarieRose, "Marie Rose",
                       GI.GT_FORTY_THIEVES, 3, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(503, BigStreets, "Big Streets",
@@ -1476,3 +1538,7 @@ registerGame(GameInfo(847, Pluto, "Pluto",
                       altnames=("Square")))
 registerGame(GameInfo(848, Malmaison, "Malmaison",
                       GI.GT_FORTY_THIEVES, 4, 0, GI.SL_MOSTLY_SKILL))
+registerGame(GameInfo(884, JacksInTheBox, "Jacks in the Box",
+                      GI.GT_FORTY_THIEVES, 2, 0, GI.SL_MOSTLY_SKILL))
+registerGame(GameInfo(895, Preference, "Preference",
+                      GI.GT_FORTY_THIEVES, 1, 0, GI.SL_LUCK))
