@@ -35,6 +35,7 @@ from pysollib.pysoltk import MfxCanvasText
 from pysollib.stack import \
         AC_RowStack, \
         BO_RowStack, \
+        DealFirstRowTalonStack, \
         DealRowTalonStack, \
         InitialDealTalonStack, \
         KingAC_RowStack, \
@@ -48,6 +49,7 @@ from pysollib.stack import \
         SC_RowStack, \
         SS_FoundationStack, \
         SS_RowStack, \
+        Spider_SS_RowStack, \
         Stack, \
         StackWrapper, \
         SuperMoveAC_RowStack, \
@@ -69,10 +71,10 @@ class Klondike(Game):
     RowStack_Class = KingAC_RowStack
     Hint_Class = KlondikeType_Hint
 
-    def createGame(self, max_rounds=-1, num_deal=1, **layout):
+    def createGame(self, max_rounds=-1, num_deal=1, rows=7, **layout):
         # create layout
         lay, s = Layout(self), self.s
-        kwdefault(layout, rows=7, waste=1, texts=1, playcards=16)
+        kwdefault(layout, rows=rows, waste=1, texts=1, playcards=16)
         self.Layout_Method.__get__(lay, lay.__class__)(**layout)
         # self.__class__.Layout_Method(lay, **layout)
         self.setSize(lay.size[0], lay.size[1])
@@ -149,6 +151,15 @@ class KlondikeByThrees(Klondike):
         Klondike.createGame(self, num_deal=3)
 
 
+# ************************************************************************
+# * Half Klondike
+# ************************************************************************
+
+class HalfKlondike(Klondike):
+    def createGame(self):
+        Klondike.createGame(self, rows=4)
+
+
 # ************************************************************************
 # * Trigon
 # ************************************************************************
@@ -210,6 +221,18 @@ class Whitehead(Klondike):
     getQuickPlayScore = Game._getSpiderQuickPlayScore
 
 
+# ************************************************************************
+# * Smokey
+# ************************************************************************
+
+class Smokey(Klondike):
+    RowStack_Class = StackWrapper(Whitehead_RowStack, base_rank=KING)
+    Hint_Class = CautiousDefaultHint
+
+    def createGame(self):
+        Klondike.createGame(self, max_rounds=3)
+
+
 # ************************************************************************
 # * Small Harp (Klondike in a different layout)
 # ************************************************************************
@@ -496,27 +519,30 @@ class BatsfordAgain(Batsford):
 
 # ************************************************************************
 # * Jumbo
+# * (Removed as it's a duplicate of Gargantua)
 # ************************************************************************
 
-class Jumbo(Klondike):
-    def createGame(self):
-        lay = Klondike.createGame(self, rows=9, max_rounds=2, round_text=True)
-        lay.createRoundText(self.s.talon, 'ne', dx=lay.XS)
-
-    def startGame(self, flip=0):
-        for i in range(9):
-            self.s.talon.dealRow(rows=self.s.rows[:i], flip=flip, frames=0)
-        self._startAndDealRowAndCards()
-
-
-class OpenJumbo(Jumbo):
-    def startGame(self):
-        Jumbo.startGame(self, flip=1)
+# class Jumbo(Klondike):
+#     def createGame(self):
+#         lay = Klondike.createGame(self, rows=9, max_rounds=2,
+#                                   round_text=True)
+#         lay.createRoundText(self.s.talon, 'ne', dx=lay.XS)
+#
+#     def startGame(self, flip=0):
+#         for i in range(9):
+#             self.s.talon.dealRow(rows=self.s.rows[:i], flip=flip, frames=0)
+#         self._startAndDealRowAndCards()
+#
+#
+# class OpenJumbo(Jumbo):
+#     def startGame(self):
+#         Jumbo.startGame(self, flip=1)
 
 
 # ************************************************************************
 # * Stonewall
 # * Flower Garden
+# * Wildflower
 # ************************************************************************
 
 class Stonewall(Klondike):
@@ -556,6 +582,10 @@ class FlowerGarden(Stonewall):
     shallHighlightMatch = Game._shallHighlightMatch_RK
 
 
+class Wildflower(FlowerGarden):
+    RowStack_Class = Spider_SS_RowStack
+
+
 # ************************************************************************
 # * King Albert
 # * Raglan
@@ -633,6 +663,7 @@ class QueenVictoria(KingAlbert):
 # ************************************************************************
 # * Jane
 # * Agnes Bernauer
+# * Agnes Two
 # ************************************************************************
 
 class Jane_Talon(OpenTalonStack):
@@ -666,9 +697,10 @@ class Jane(Klondike):
     def createGame(self, max_rounds=1, rows=7, reserves=7, playcards=16):
         lay, s = Layout(self), self.s
         maxrows = max(rows, 7)
-        w = lay.XM+maxrows*lay.XS+lay.XM+2*lay.XS
-        h = max(lay.YM+2*lay.YS+playcards*lay.YOFFSET+lay.TEXT_HEIGHT,
-                lay.YM+4*lay.YS)
+        w = lay.XM + maxrows * lay.XS + lay.XM + 2 * lay.XS
+        h = max(lay.YM + 2 * lay.YS + playcards * lay.YOFFSET
+                + lay.TEXT_HEIGHT,
+                lay.YM + ((reserves + 1) / 2) * lay.YS)
         self.setSize(w, h)
 
         x, y = lay.XM, lay.YM
@@ -677,10 +709,11 @@ class Jane(Klondike):
         x += lay.XS
         s.waste = WasteStack(x, y, self)
 
-        x += 2*lay.XS
+        x += (rows - 1 - (4 * self.gameinfo.decks)) * lay.XS
         for i in range(4):
-            s.foundations.append(self.Foundation_Class(x, y, self, suit=i))
-            x += lay.XS
+            for j in range(self.gameinfo.decks):
+                s.foundations.append(self.Foundation_Class(x, y, self, suit=i))
+                x += lay.XS
 
         x, y = lay.XM, lay.YM+lay.YS+lay.TEXT_HEIGHT
         for i in range(rows):
@@ -734,6 +767,11 @@ class AgnesBernauer(Jane):
         Jane.startGame(self, flip=1)
 
 
+class AgnesTwo(AgnesBernauer):
+    def createGame(self):
+        Jane.createGame(self, rows=10, reserves=10, playcards=20)
+
+
 # ************************************************************************
 # * Senate
 # ************************************************************************
@@ -741,7 +779,6 @@ class AgnesBernauer(Jane):
 class Senate(Jane):
 
     def createGame(self, rows=4):
-
         playcards = 10
 
         lay, s = Layout(self), self.s
@@ -869,6 +906,8 @@ class Lanes(Klondike):
 
 # ************************************************************************
 # * Thirty Six
+# * Six By Six
+# * Taking Silk
 # ************************************************************************
 
 class ThirtySix(Klondike):
@@ -884,7 +923,7 @@ class ThirtySix(Klondike):
             if r.cards:
                 c = r.cards[-1]
                 for f in self.s.foundations:
-                    if f.acceptsCards(r, [c]):
+                    if f.acceptsCards(r, [c]) and c.rank == ACE:
                         self.moveMove(1, r, f, frames=4, shadow=0)
                         return 1
         return 0
@@ -901,6 +940,27 @@ class ThirtySix(Klondike):
     shallHighlightMatch = Game._shallHighlightMatch_RK
 
 
+class SixBySix(ThirtySix):
+
+    Talon_Class = StackWrapper(DealFirstRowTalonStack, max_move=0)
+    RowStack_Class = StackWrapper(Spider_SS_RowStack, base_rank=ANY_RANK)
+
+    def createGame(self):
+        Klondike.createGame(self, rows=6, max_rounds=1, waste=0)
+
+    def startGame(self):
+        self.startDealSample()
+        for i in range(6):
+            self.s.talon.dealRow()
+            while True:
+                if not self._fillOne():
+                    break
+
+
+class TakingSilk(ThirtySix):
+    pass
+
+
 # ************************************************************************
 # * Q.C.
 # ************************************************************************
@@ -1504,7 +1564,7 @@ registerGame(GameInfo(221, Stonewall, "Stonewall",
                       GI.GT_RAGLAN, 1, 0, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(222, FlowerGarden, "Flower Garden",
                       GI.GT_RAGLAN | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL,
-                      altnames=("The Bouquet", "The Garden",)))
+                      altnames=("The Bouquet", "The Garden", "Le Parterre")))
 registerGame(GameInfo(233, KingAlbert, "King Albert",
                       GI.GT_RAGLAN | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL,
                       altnames=("Idiot's Delight",)))
@@ -1518,10 +1578,10 @@ registerGame(GameInfo(236, AgnesBernauer, "Agnes Bernauer",
                       GI.GT_RAGLAN, 1, 0, GI.SL_BALANCED))
 registerGame(GameInfo(263, Phoenix, "Phoenix",
                       GI.GT_RAGLAN | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL))
-registerGame(GameInfo(283, Jumbo, "Jumbo",
-                      GI.GT_KLONDIKE, 2, 1, GI.SL_BALANCED))
-registerGame(GameInfo(333, OpenJumbo, "Open Jumbo",
-                      GI.GT_KLONDIKE, 2, 1, GI.SL_BALANCED))
+# registerGame(GameInfo(283, Jumbo, "Jumbo",
+#                       GI.GT_KLONDIKE, 2, 1, GI.SL_BALANCED))
+# registerGame(GameInfo(333, OpenJumbo, "Open Jumbo",
+#                       GI.GT_KLONDIKE, 2, 1, GI.SL_BALANCED))
 registerGame(GameInfo(326, Lanes, "Lanes",
                       GI.GT_KLONDIKE, 1, 1, GI.SL_BALANCED))
 registerGame(GameInfo(327, ThirtySix, "Thirty Six",
@@ -1611,3 +1671,16 @@ registerGame(GameInfo(849, RelaxedRaglan, "Relaxed Raglan",
                       GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(852, Guardian, "Guardian",
                       GI.GT_KLONDIKE, 1, -1, GI.SL_BALANCED))
+registerGame(GameInfo(855, HalfKlondike, "Half Klondike",
+                      GI.GT_KLONDIKE | GI.GT_STRIPPED, 1, -1, GI.SL_BALANCED,
+                      suits=(1, 2)))
+registerGame(GameInfo(861, Wildflower, "Wildflower",
+                      GI.GT_RAGLAN | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL))
+registerGame(GameInfo(869, Smokey, "Smokey",
+                      GI.GT_KLONDIKE, 1, 2, GI.SL_BALANCED))
+registerGame(GameInfo(873, AgnesTwo, "Agnes Two",
+                      GI.GT_RAGLAN, 2, 0, GI.SL_BALANCED))
+registerGame(GameInfo(888, SixBySix, "Six by Six",
+                      GI.GT_1DECK_TYPE, 1, 0, GI.SL_BALANCED))
+registerGame(GameInfo(893, TakingSilk, "Taking Silk",
+                      GI.GT_KLONDIKE, 2, 0, GI.SL_BALANCED))
