@@ -21,6 +21,8 @@
 #
 # ---------------------------------------------------------------------------##
 
+import math
+
 from pysollib.game import Game
 from pysollib.gamedb import GI, GameInfo, registerGame
 from pysollib.hint import DefaultHint
@@ -339,6 +341,7 @@ class SimplePairs(MonteCarlo):
 
 # ************************************************************************
 # * Block Ten
+# * Simple Tens
 # ************************************************************************
 
 class BlockTen_RowStack(MonteCarlo_RowStack):
@@ -361,6 +364,11 @@ class BlockTen(SimplePairs):
         return len(self.s.foundations[0].cards) == 48
 
 
+class SimpleTens(BlockTen):
+    def isGameWon(self):
+        return len(self.s.foundations[0].cards) == 36
+
+
 # ************************************************************************
 # * Neighbour
 # ************************************************************************
@@ -430,6 +438,7 @@ class Neighbour(MonteCarlo):
 
 # ************************************************************************
 # * Fourteen
+# * Double Fourteen
 # ************************************************************************
 
 class Fourteen_RowStack(MonteCarlo_RowStack):
@@ -450,21 +459,21 @@ class Fourteen(Game):
     # game layout
     #
 
-    def createGame(self):
+    def createGame(self, colsperrow=6):
         # create layout
         l, s = Layout(self), self.s
 
         # set window
-        self.setSize(l.XM + 7*l.XS, l.YM + 5*l.YS)
+        self.setSize(l.XM + (colsperrow + 1) * l.XS, l.YM + 5 * l.YS)
 
         # create stacks
         for i in (0, 2.5):
-            for j in range(6):
+            for j in range(colsperrow):
                 x, y = l.XM + j*l.XS, l.YM + i*l.YS
                 s.rows.append(self.RowStack_Class(x, y, self,
                                                   max_move=1, max_accept=1,
                                                   dir=0, base_rank=NO_RANK))
-        x, y = l.XM + 6*l.XS, l.YM
+        x, y = l.XM + colsperrow * l.XS, l.YM
         s.foundations.append(self.Foundation_Class(x, y, self, suit=ANY_SUIT,
                              max_move=0, max_cards=52, base_rank=ANY_RANK))
         l.createText(s.foundations[0], "s")
@@ -490,6 +499,16 @@ class Fourteen(Game):
         return card1.rank + card2.rank == 12
 
 
+class DoubleFourteen(Fourteen):
+    def createGame(self):
+        Fourteen.createGame(self, colsperrow=9)
+
+    def startGame(self):
+        self._startDealNumRows(4)
+        self.s.talon.dealRow()
+        self.s.talon.dealRow(rows=self.s.rows[:14])
+
+
 # ************************************************************************
 # * Nestor
 # * Double Nestor
@@ -645,21 +664,26 @@ class Vertical(Nestor):
 class TheWish(Game):
 
     FILL_STACKS_AFTER_DROP = False
+    ROWS = 8
 
     def createGame(self):
         # create layout
         l, s = Layout(self), self.s
 
         # set window
-        self.setSize(l.XM+6*l.XS, 2*l.YM+2*l.YS+6*l.YOFFSET)
+        self.setSize(l.XM + ((self.ROWS / 2) + 2) * l.XS,
+                     2 * l.YM + 2 * l.YS + 6 * l.YOFFSET)
 
+        currentrow = 0
         # create stacks
         for i in range(2):
-            for j in range(4):
-                x, y = l.XM + j*l.XS, l.YM+i*(l.YM+l.YS+3*l.YOFFSET)
-                s.rows.append(Nestor_RowStack(x, y, self,
-                                              max_move=1, max_accept=1,
-                                              dir=0, base_rank=NO_RANK))
+            for j in range(math.ceil(self.ROWS / 2)):
+                if currentrow < self.ROWS:
+                    x, y = l.XM + j*l.XS, l.YM+i*(l.YM+l.YS+3*l.YOFFSET)
+                    s.rows.append(Nestor_RowStack(x, y, self,
+                                                  max_move=1, max_accept=1,
+                                                  dir=0, base_rank=NO_RANK))
+                    currentrow += 1
 
         x, y = self.width - l.XS, l.YM
         s.talon = InitialDealTalonStack(x, y, self)
@@ -701,6 +725,15 @@ class TheWishOpen(TheWish):
     def startGame(self):
         self._startDealNumRowsAndDealSingleRow(3)
 
+
+class PatientPairs(TheWish):
+    ROWS = 13
+
+
+class PatientPairsOpen(TheWishOpen):
+    ROWS = 13
+
+
 # ************************************************************************
 # * Der letzte Monarch (The last Monarch)
 # ************************************************************************
@@ -972,7 +1005,7 @@ registerGame(GameInfo(90, SimpleCarlo, "Simple Carlo",
                       GI.GT_PAIRING_TYPE, 1, 0, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(91, SimplePairs, "Simple Pairs",
                       GI.GT_PAIRING_TYPE, 1, 0, GI.SL_LUCK,
-                      altnames=("Jamestown",)))
+                      altnames=("Jamestown", "Pirate Gold", "Treasure Hunt")))
 registerGame(GameInfo(92, Neighbour, "Neighbour",
                       GI.GT_PAIRING_TYPE, 1, 0, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(96, Fourteen, "Fourteen",
@@ -1011,3 +1044,16 @@ registerGame(GameInfo(810, Quatorze, "Quatorze",
                       GI.GT_PAIRING_TYPE, 1, 0, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(829, BlockTen, "Block Ten",
                       GI.GT_PAIRING_TYPE, 1, 0, GI.SL_LUCK))
+registerGame(GameInfo(862, SimpleTens, "Simple Tens",
+                      GI.GT_PAIRING_TYPE | GI.GT_STRIPPED, 1, 0, GI.SL_LUCK,
+                      ranks=(0, 1, 2, 3, 4, 5, 6, 7, 8),
+                      altnames=("Add Up Tens",)))
+registerGame(GameInfo(867, DoubleFourteen, "Double Fourteen",
+                      GI.GT_PAIRING_TYPE | GI.GT_OPEN, 2, 0,
+                      GI.SL_MOSTLY_LUCK))
+registerGame(GameInfo(874, PatientPairs, "Patient Pairs",
+                      GI.GT_PAIRING_TYPE, 1, 0, GI.SL_MOSTLY_LUCK,
+                      altnames=("Isabel",)))
+registerGame(GameInfo(875, PatientPairsOpen, "Patient Pairs (Open)",
+                      GI.GT_PAIRING_TYPE | GI.GT_OPEN, 1, 0,
+                      GI.SL_MOSTLY_SKILL, rules_filename="patientpairs.html"))
