@@ -994,10 +994,11 @@ class Aglet(Game):
 
         decks = self.gameinfo.decks
         l, s = Layout(self), self.s
-        self.setSize(l.XM+(reserves+0.5+rows)*l.XS,
-                     l.YM+max(2*l.YS+7*l.YOFFSET, l.YS+playcards*l.YOFFSET))
+        self.setSize(l.XM + (reserves + 0.5+rows) * l.XS,
+                     l.YM + max(2 * l.YS + 7 * l.YOFFSET,
+                                l.YS + playcards * l.YOFFSET))
 
-        x, y = self.width-l.XS, self.height-l.YS
+        x, y = l.XM, self.height-l.YS
         s.talon = InitialDealTalonStack(x, y, self)
 
         x, y = l.XM, l.YM
@@ -1007,12 +1008,12 @@ class Aglet(Game):
             s.reserves.append(stack)
             x += l.XS
 
-        x, y = l.XM + (reserves+0.5+(rows-decks*4)/2.0)*l.XS, l.YM
+        x, y = l.XM + (reserves + 0.5 + (rows-decks * 4) / 2.0) * l.XS, l.YM
         for i in range(4):
             s.foundations.append(RK_FoundationStack(x, y, self, suit=ANY_SUIT))
             x += l.XS
 
-        x, y = l.XM+(reserves+0.5)*l.XS, l.YM+l.YS
+        x, y = l.XM+(reserves + 0.5) * l.XS, l.YM + l.YS
         for i in range(rows):
             s.rows.append(BasicRowStack(x, y, self, base_rank=NO_RANK))
             x += l.XS
@@ -1102,7 +1103,7 @@ class Ladybug(Game):
             x = x + l.XS
         self.setRegion(s.rows, (x0-l.XS//2, y-l.CH//2, 999999, 999999))
         x, y = l.XM, l.YM
-        s.talon = Ladybug_Talon(x, y, self, max_rounds=-1, num_deal=3)
+        s.talon = Ladybug_Talon(x, y, self, max_rounds=-2, num_deal=3)
         l.createText(s.talon, 'ne')
         y = y + l.YS
         s.waste = Ladybug_Waste(x, y, self)
@@ -1191,7 +1192,7 @@ class Ladybug(Game):
 # register the game
 registerGame(GameInfo(257, Numerica, "Numerica",
                       GI.GT_NUMERICA | GI.GT_CONTRIB, 1, 0, GI.SL_BALANCED,
-                      altnames=("Sir Tommy", "Old Patience",)))
+                      altnames=("Sir Tommy", "Old Patience", "Try Again")))
 registerGame(GameInfo(171, LadyBetty, "Lady Betty",
                       GI.GT_NUMERICA, 1, 0, GI.SL_BALANCED))
 registerGame(GameInfo(355, Frog, "Frog",
@@ -1239,4 +1240,4 @@ registerGame(GameInfo(760, Aglet, "Aglet",
                       GI.GT_1DECK_TYPE | GI.GT_OPEN | GI.GT_ORIGINAL, 1, 0,
                       GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(836, Ladybug, "Ladybug",
-                      GI.GT_1DECK_TYPE, 1, -1, GI.SL_BALANCED))
+                      GI.GT_1DECK_TYPE, 1, -2, GI.SL_BALANCED))
