@@ -40,6 +40,7 @@ from pysollib.stack import \
     WasteStack, \
     WasteTalonStack, \
     Yukon_AC_RowStack, \
+    Yukon_BO_RowStack, \
     Yukon_SS_RowStack
 from pysollib.util import ANY_SUIT, KING
 
@@ -100,17 +101,8 @@ class RussianSolitaire(Yukon):
 # * Moosehide (build down in any suit but the same)
 # ************************************************************************
 
-class Moosehide_RowStack(Yukon_AC_RowStack):
-    def _isYukonSequence(self, c1, c2):
-        return (c1.suit != c2.suit and c1.rank == c2.rank+1)
-
-    def getHelp(self):
-        return _('Tableau. Build down in any suit but the same, can move '
-                 'any face-up cards regardless of sequence.')
-
-
 class Moosehide(Yukon):
-    RowStack_Class = StackWrapper(Moosehide_RowStack, base_rank=KING)
+    RowStack_Class = StackWrapper(Yukon_BO_RowStack, base_rank=KING)
 
     def shallHighlightMatch(self, stack1, card1, stack2, card2):
         return (card1.suit != card2.suit and
@@ -455,6 +447,7 @@ class Panopticon(TenAcross):
 
 # ************************************************************************
 # * Australian Patience
+# * Tasmanian Patience
 # * Raw Prawn
 # * Bim Bom
 # ************************************************************************
@@ -463,11 +456,12 @@ class AustralianPatience(RussianSolitaire):
 
     RowStack_Class = StackWrapper(Yukon_SS_RowStack, base_rank=KING)
 
-    def createGame(self, rows=7):
+    def createGame(self, rows=7, max_rounds=1, num_deal=1):
         l, s = Layout(self), self.s
         Layout.klondikeLayout(l, rows=rows, waste=1)
         self.setSize(l.size[0], l.size[1])
-        s.talon = WasteTalonStack(l.s.talon.x, l.s.talon.y, self, max_rounds=1)
+        s.talon = WasteTalonStack(l.s.talon.x, l.s.talon.y, self,
+                                  max_rounds=max_rounds, num_deal=num_deal)
         s.waste = WasteStack(l.s.waste.x, l.s.waste.y, self)
         for r in l.s.foundations:
             s.foundations.append(
@@ -480,6 +474,11 @@ class AustralianPatience(RussianSolitaire):
         self._startDealNumRowsAndDealRowAndCards(3)
 
 
+class TasmanianPatience(AustralianPatience):
+    def createGame(self):
+        AustralianPatience.createGame(self, max_rounds=-1, num_deal=3)
+
+
 class RawPrawn(AustralianPatience):
     RowStack_Class = Yukon_SS_RowStack
 
@@ -809,3 +808,5 @@ registerGame(GameInfo(732, Wave, "Wave",
                       GI.GT_YUKON | GI.GT_ORIGINAL, 2, 0, GI.SL_BALANCED))
 registerGame(GameInfo(826, YukonicPlague, "Yukonic Plague",
                       GI.GT_YUKON, 1, 0, GI.SL_BALANCED))
+registerGame(GameInfo(857, TasmanianPatience, "Tasmanian Patience",
+                      GI.GT_YUKON, 1, -1, GI.SL_BALANCED))
