@@ -139,7 +139,13 @@ def getprefdir(package):
         from pysollib.kivy.LApp import get_platform
         plat = get_platform()
         if plat == 'android':
-            os.environ['HOME'] = '/sdcard'
+            from pysollib.kivy.androidperms import getStoragePerm
+            from android.storage import primary_external_storage_path
+            from android.storage import app_storage_path
+            if getStoragePerm():
+                os.environ['HOME'] = primary_external_storage_path()
+            else:
+                os.environ['HOME'] = app_storage_path()
 
     if os.name == "nt":
         return win32_getprefdir(package)
