@@ -480,7 +480,8 @@ class AllGamesFrame(ttk.Frame):
 
     def fillTreeview(self, player):
         if self.tree_items:
-            self.tree.delete(tuple(self.tree_items))
+            for item in self.tree.get_children():
+                self.tree.delete(item)
             self.tree_items = []
         self.formatter.writeStats(player, sort_by=self.sort_by)
         if self.dialog.buttons:
