@@ -25,7 +25,9 @@ def createToolbarMenu(menubar, menu):
     tearoff = menu.cget('tearoff')
     data_dir = os.path.join(menubar.app.dataloader.dir, 'images', 'toolbar')
     submenu = MfxMenu(menu, label=n_('Icon Style'), tearoff=tearoff)
-    for f in os.listdir(data_dir):
+    styledirs = os.listdir(data_dir)
+    styledirs.sort()
+    for f in styledirs:
         d = os.path.join(data_dir, f)
         if os.path.isdir(d) and os.path.exists(os.path.join(d, 'small')):
             name = f.replace('_', ' ').capitalize()
@@ -383,6 +385,10 @@ class PysolMenubarTkCommon:
         submenu.add_command(
             label=n_("&All games"), command=lambda:
             self.mSelectRandomGame('all'), accelerator=m+"R")
+        submenu.add_separator()
+        submenu.add_command(
+            label=n_("&Games played"),
+            command=lambda: self.mSelectRandomGame('played'))
         submenu.add_command(
             label=n_("Games played and &won"),
             command=lambda: self.mSelectRandomGame('won'))
@@ -739,6 +745,11 @@ class PysolMenubarTkCommon:
         createToolbarMenu(self, submenu)
         submenu = MfxMenu(menu, label=n_("Stat&usbar"))
         createStatusbarMenu(self, submenu)
+        if not USE_PIL:
+            menu.add_checkbutton(
+                label=n_("Save games &geometry"),
+                variable=self.tkopt.save_games_geometry,
+                command=self.mOptSaveGamesGeometry)
         menu.add_checkbutton(
             label=n_("&Demo logo"), variable=self.tkopt.demo_logo,
             command=self.mOptDemoLogo)
